eric6/Preferences/ShortcutsDialog.py

branch
maintenance
changeset 8043
0acf98cd089a
parent 7924
8a96736d465e
parent 7960
e8fc383322f7
child 8176
31965986ecd1
diff -r 866adc8c315b -r 0acf98cd089a eric6/Preferences/ShortcutsDialog.py
--- a/eric6/Preferences/ShortcutsDialog.py	Sun Jan 17 13:53:08 2021 +0100
+++ b/eric6/Preferences/ShortcutsDialog.py	Mon Feb 01 10:38:16 2021 +0100
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a dialog for the configuration of eric6's keyboard
+Module implementing a dialog for the configuration of eric's keyboard
 shortcuts.
 """
 
@@ -25,7 +25,7 @@
 
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
     """
     Class implementing a dialog for the configuration of eric6's keyboard
     shortcuts.
     
     @signal updateShortcuts() emitted when the user pressed the dialogs OK
@@ -92,9 +92,9 @@
         
         @param category reference to the category item (QTreeWidgetItem)
         @param action reference to the keyboard action (E5Action)
-        @keyparam noCheck flag indicating that no uniqueness check should
+        @param noCheck flag indicating that no uniqueness check should
             be performed (boolean)
-        @keyparam objectType type of the object (string). Objects of the same
+        @param objectType type of the object (string). Objects of the same
             type are not checked for duplicate shortcuts.
         """
         itm = QTreeWidgetItem(
@@ -195,7 +195,7 @@
         
         else:
             self.helpViewerItem = self.__generateCategoryItem(
-                self.tr("eric6 Web Browser"))
+                self.tr("eric Web Browser"))
             for act in helpViewer.getActions():
                 self.__generateShortcutItem(self.helpViewerItem, act, True)
         
@@ -25,7 +25,7 @@
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
     """
-    Class implementing a dialog for the configuration of eric6's keyboard
+    Class implementing a dialog for the configuration of eric's keyboard
     shortcuts.
     

eric ide

mercurial